@@ -80,7 +80,8 @@ import gvar as _gvar
 # add extras and utilities to lsqfit 
 from ._extras import empbayes_fit, wavg
 from ._utilities import dot as _util_dot
-from ._utilities import multifit, multiminex, gammaQ
+from ._utilities import multifit, multiminex
+from gvar import gammaQ
 from ._version import version as __version__
 
 
@@ -103,7 +104,11 @@ class nonlinear_fit(object):
     fit are in ``fit.chi2``, ``fit.dof``, ``fit.logGBF``, ``fit.nit``, and
     ``fit.time``, respectively. Results for individual parameters in
     ``fit.p`` are of type |GVar|, and therefore carry information about
-    errors and correlations with other parameters.
+    errors and correlations with other parameters. The fit data and prior 
+    can be recovered using ``fit.x`` (equals ``False`` if there is no ``x``),
+    ``fit.y``, and ``fit.prior``; the data and prior are corrected for the
+    *svd* cut, if there is one (that is, their covariance matrices have been 
+    modified in accordance with the *svd* cut).
         
     :param data: Data to be fit by :class:`lsqfit.nonlinear_fit`. It can 
         have any of the following formats:
@@ -213,14 +218,13 @@ class nonlinear_fit(object):
         self.p0file = p0 if isinstance(p0, str) else None
         self.p0 = p0 if self.p0file is None else None
         self.fcn = fcn
-        self.prior = prior
         self._p = None
         self._palt = None
         self.debug = debug
         cpu_time = time.clock()
         
         # unpack prior,data,fcn,p0 to reconfigure for multifit 
-        prior = _unpack_gvars(self.prior)
+        prior = _unpack_gvars(prior)
         if (debug and prior is not None and
             not all(isinstance(pri, _gvar.GVar) for pri in prior.flat)):
             raise TypeError("Priors must be GVars.")
@@ -415,14 +419,24 @@ class nonlinear_fit(object):
             and v2, while label is assembled from the key/index of the
             entry.
             """
+            def nstar(v1, v2):
+                sdev = max(v1.sdev, v2.sdev)
+                nstar = int(abs(v1.mean - v2.mean) / sdev)
+                if nstar > 5:
+                    nstar = 5
+                elif nstar < 1:
+                    nstar = 0
+                return '  ' + nstar * '*'
             ct = 0
             ans = []
             width = [0,0,0]
+            stars = []
             if v1.shape is None:
                 # BufferDict 
                 for k in v1:
                     ktag = str(k)
                     if v1.isscalar(k):
+                        stars.append(nstar(v1[k], v2[k]))
                         if ct%stride != 0:
                             ct += 1
                             continue
@@ -444,6 +458,7 @@ class nonlinear_fit(object):
                     else:
                         ktag = ktag + " "
                         for i in numpy.ndindex(v1[k].shape):
+                            stars.append(nstar(v1[k][i], v2[k][i]))
                             if ct%stride != 0:
                                 ct += 1
                                 continue
@@ -469,6 +484,7 @@ class nonlinear_fit(object):
                 # numpy array 
                 v2 = numpy.asarray(v2)
                 for k in numpy.ndindex(v1.shape):
+                    stars.append(nstar(v1[k], v2[k]))
                     if ct%stride != 0:
                         ct += 1
                         continue
@@ -490,6 +506,7 @@ class nonlinear_fit(object):
                     ct += 1
                 
             collect.width = width
+            collect.stars = stars
             return ans
         
         # build header 
@@ -529,11 +546,11 @@ class nonlinear_fit(object):
                 prior = self.p0 + _gvar.gvar(0,float('inf'))
         data = collect(self.palt,prior,style=pstyle,stride=1)
         w1,w2,w3 = collect.width
-        fst = "%%%ds%s%%%ds%s[ %%%ds ]\n" % ( #
+        fst = "%%%ds%s%%%ds%s[ %%%ds ]" % ( #
             max(w1,15), 3 * ' ', 
             max(w2,10), int(max(w2,10)/2) * ' ', max(w3,10))
-        for di in data:
-            table += fst % tuple(di)
+        for di,stars in zip(data, collect.stars):
+            table += (fst % tuple(di)) + stars + '\n'
         
         # tabulate settings 
         def svdfmt(x):
@@ -585,8 +602,8 @@ class nonlinear_fit(object):
         fst = "%%%ds%%%ds%%%ds\n" % (w1, w2, w3)
         table += fst % clabels
         table += (w1 + w2 + w3) * "-" + "\n"
-        for di in data:
-            table += fst % tuple(di)
+        for di, stars in zip(data, collect.stars):
+            table += fst[:-1] % tuple(di) + stars + '\n'
         
         return table + settings
     
@@ -633,7 +650,104 @@ class nonlinear_fit(object):
             else:
                 pickle.dump(dict(self.pmean), f) # dump as a dict
     
-    def bootstrap_iter(self, n=None, datalist=None):
+    def simulated_fit_iter(self, n, pexact=None, **kargs):
+        """ Iterator that returns simulation copies of a fit.
+
+        Fit reliability can be tested using simulated data which
+        replaces the mean values in ``self.y`` with random numbers
+        drawn from a distribution whose mean equals ``self.fcn(pexact)`` 
+        and whose covariance matrix is the same as ``self.y``'s. Simulated
+        data is very similar to the original fit data, ``self.y``, 
+        but corresponds to a world where the correct values for
+        the parameters (*i.e.*, averaged over many simulated data
+        sets) are given by ``pexact``. ``pexact`` is usually taken
+        equal to ``fit.pmean``.
+
+        Each iteration of the iterator creates new simulated data,
+        with different random numbers and fits it, returning the 
+        the :class:`lsqfit.nonlinear_fit` that results. The simulated
+        data has the same covariance matrix as ``fit.y``.
+        Typical usage is::
+
+            ...
+            fit = nonlinear_fit(...)
+            ...
+            for sfit in fit.simulated_fit_iter(n=3):
+                ... verify that sfit.p agrees with fit.pmean within errors ...
+
+        Only a few iterations are needed to get a sense of the fit's 
+        reliability since we know the correct answer in each case 
+        (``pexact``, equal to ``fit.pmean`` in this example). The simulated
+        fit's output results should agree with ``pexact`` within 
+        the simulated fit's errors.
+
+        Simulated fits can also be used to correct for biases in the fit's 
+        output parameters or functions of them, should non-Gaussian behavior 
+        arise. This is possible, again, because we know the correct value for 
+        every parameter before we do the fit. Simulated fits provide 
+        a faster alternative to a traditional bootstrap analysis.
+
+        :param n: Maximum number of iterations (equals infinity if ``None``).
+        :type n: integer or ``None``
+        :param pexact: Fit-parameter values for the underlying distribution
+            used to generate simulated data; replaced by ``self.pmean`` if 
+            is ``None`` (default).
+        :type pexact: ``None`` or array or dictionary of numbers
+        :returns: An iterator that returns :class:`lsqfit.nonlinear_fit`\s
+            for different simulated data.
+
+        Note that additional keywords can be added to overwrite keyword 
+        arguments in :class:`lsqfit.nonlinear_fit`.
+        """
+        pexact = self.pmean if pexact is None else pexact
+        # Note: don't need svdcut/svdnum since these are built into the data_iter
+        fargs = dict(
+            fcn=self.fcn, svdcut=None, svdnum=None, prior=self.prior, p0=pexact
+            )
+        fargs.update(self.fitterargs)
+        fargs.update(kargs)
+        for yb in self._simulated_data_iter(n, pexact=pexact):
+            fit = nonlinear_fit(data=(self.x, yb), **fargs)
+            fit.pexact = pexact
+            yield fit
+
+    def _simulated_data_iter(self, n, pexact=None):
+        """ Iterator that returns simulated data based upon a fit's data.
+
+        Simulated data is generated from a fit's data ``fit.y`` by
+        replacing the mean values in that data with random numbers
+        drawn from a distribution whose mean is ``self.fcn(pexact)`` 
+        and whose covariance matrix is the same as that of ``self.y``. 
+        Each iteration of the iterator returns new simulated data,
+        with different random numbers for the means and a covariance
+        matrix equal to that of ``self.y``. This iterator is used by
+        ``self.simulated_fit_iter``.
+
+        :param n: Maximum number of iterations (equals infinity if ``None``).
+        :type n: integer or ``None``
+        :param pexact: Fit-parameter values for the underlying distribution
+            used to generate simulated data; replaced by ``self.pmean`` if 
+            is ``None`` (default).
+        :type pexact: ``None`` or array or dictionary of numbers
+        :returns: An iterator that returns :class:`lsqfit.nonlinear_fit`\s
+            for different simulated data.
+        """
+        pexact = self.pmean if pexact is None else pexact
+        f = self.fcn(pexact) if self.x is False else self.fcn(self.x, pexact)
+        if isinstance(self.y, _gvar.BufferDict):
+            # y,f dictionaries; fresh copy of y, reorder f
+            y = _gvar.BufferDict(self.y)
+            tmp_f = _gvar.BufferDict([(k, f[k]) for k in y])
+            y.buf += tmp_f.buf - _gvar.mean(y.buf)
+        else:
+            # y,f arrays; fresh copy of y
+            y = numpy.array(self.y)
+            y += numpy.asarray(f) - _gvar.mean(y) 
+        return _gvar.bootstrap_iter(y, n)        
+
+    simulate_iter = simulated_fit_iter
+
+    def bootstrapped_fit_iter(self, n=None, datalist=None):
         """ Iterator that returns bootstrap copies of a fit.
             
         A bootstrap analysis involves three steps: 1) make a large number
@@ -657,7 +771,7 @@ class nonlinear_fit(object):
             ...
             fit = lsqfit.nonlinear_fit(...)
             ...
-            for bsfit in fit.bootstrap_iter(n=100, datalist=datalist):
+            for bsfit in fit.bootstrapped_fit_iter(n=100, datalist=datalist):
                 ... analyze fit parameters in bsfit.pmean ...
             
                         
@@ -704,7 +818,8 @@ class nonlinear_fit(object):
                     fit = nonlinear_fit(data=datab, prior=next(piter), 
                                         p0=self.pmean, **fargs)
                     yield fit
-    
+
+    bootstrap_iter = bootstrapped_fit_iter
 
 # decorator for fit function allowing log/sqrt-normal distributions
 class transform_p(object):
