@@ -186,13 +186,13 @@ class test_lsqfit(unittest.TestCase,ArrayTests):
             '  chi2/dof [dof] = 0.3 [2]    Q = 0.74    logGBF = -2.9682    itns = 2', 
             '', 
             'Parameters:', 
-            '              p    0.90 (44)     [  0.0 (2.0) ]', 
+            '              p    0.90 (44)     [  0.0 (2.0) ]  ', 
             '', 
             'Fit:', 
             '      key       y[key]    f(p)[key]', 
             '-----------------------------------', 
-            '        a    1.5 (1.0)    0.90 (44)', 
-            '        b    0.80 (50)    0.90 (44)',
+            '        a    1.5 (1.0)    0.90 (44)  ', 
+            '        b    0.80 (50)    0.90 (44)  ',
             '',
             'Settings:', 
             '  svdcut = (1e-15,None)   svdnum = (None,None)    reltol/abstol = 0.0001/0', 
@@ -204,7 +204,7 @@ class test_lsqfit(unittest.TestCase,ArrayTests):
             '  chi2/dof [dof] = 0.3 [2]    Q = 0.74    logGBF = -2.9682    itns = 2', 
             '', 
             'Parameters:', 
-            '              p   0.895238 +- 0.436436          [     0 +- 2 ]', 
+            '              p   0.895238 +- 0.436436          [     0 +- 2 ]  ', 
             '', 
             'Settings:', 
             '  svdcut = (1e-15,None)   svdnum = (None,None)    reltol/abstol = 0.0001/0', 
@@ -217,7 +217,7 @@ class test_lsqfit(unittest.TestCase,ArrayTests):
             '  chi2/dof [dof] = 0.3 [2]    Q = 0.74    logGBF = -2.9682    itns = 2', 
             '', 
             'Parameters:', 
-            '              p    0.90 (44)     [  0.0 (2.0) ]', 
+            '              p    0.90 (44)     [  0.0 (2.0) ]  ', 
             ''])
         self.assertEqual(out, fit.format(pstyle='m'))
         self.assert_gvclose(fit.p['p'], wavg([y['a'],y['b'],prior['p']]))
@@ -236,13 +236,13 @@ class test_lsqfit(unittest.TestCase,ArrayTests):
             '  chi2/dof [dof] = 0.8 [1]    Q = 0.37    logGBF = None    itns = 2', 
             '', 
             'Parameters:', 
-            '              p    1.09 (19)     [ 0.0 +- inf ]', 
+            '              p    1.09 (19)     [ 0.0 +- inf ]  ', 
             '', 
             'Fit:', 
             '     x[k]         y[k]    f(x[k],p)', 
             '-----------------------------------', 
-            '        1    1.30 (30)    1.09 (19)', 
-            '        2    1.90 (50)    2.19 (38)', 
+            '        1    1.30 (30)    1.09 (19)  ', 
+            '        2    1.90 (50)    2.19 (38)  ', 
             '', 
             'Settings:', 
             '  svdcut = (None,None)   svdnum = (None,None)    reltol/abstol = 0.0001/0', 
@@ -1076,6 +1076,25 @@ class test_lsqfit(unittest.TestCase,ArrayTests):
         self.assertAlmostEqual(err["not y","y"],0.0)
         self.assertAlmostEqual(err["not y","other prior"],0.0)
     
+    def test_fit_iter(self):
+        " fit.simulated_fit_iter "
+        y = gv.gvar(['2.1(1.2)', '1.7(5.2)', '2.2(3)', '3.2(1.5)', '1.9(2)'])
+        y[1:] = (y[1:] + y[:1]) / 2.
+        def fcn(p):
+            return len(y) * [p[0]]
+        prior = [gv.gvar(2,1)]
+        for svdcut in [None, 5e-1]:
+            fit = nonlinear_fit(data=y, fcn=fcn, prior=prior, svdcut=svdcut)
+            means = []
+            N = 100
+            for sfit in fit.simulated_fit_iter(N):
+                means.append(sfit.p[0].mean)
+            self.assertAlmostEqual(fit.p[0].sdev, sfit.p[0].sdev)
+            self.assertLess(
+                abs(np.average(means) - fit.p[0].mean), 
+                5 * fit.p[0].sdev / N ** 0.5
+                )
+
     def test_normal(self):
         " log-normal priors "
         y = gv.gvar([
